==> adams-twitter-0.3.32-sources.jar: adams/flow/sink/Tweet.java <==
/*
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * Tweet.java
 * Copyright (C) 2012 University of Waikato, Hamilton, New Zealand
 */
package adams.flow.sink;

import adams.flow.core.TwitterUtils;
import adams.flow.standalone.TwitterConnection;

/**
 <!-- globalinfo-start -->
 <!-- globalinfo-end -->
 *
 <!-- flow-summary-start -->
 <!-- flow-summary-end -->
 *
 <!-- options-start -->
 <!-- options-end -->
 *
 * @author  fracpete (fracpete at waikato dot ac dot nz)
 * @version $Revision: 4932 $
 */
public class Tweet
  extends AbstractSink {

  /** for serialization. */
  private static final long serialVersionUID = 7284342863526697831L;

  /** for accessing the twitter API. */
  protected twitter4j.Twitter m_Twitter;

  /**
   * Returns a string describing the object.
   *
   * @return 			a description suitable for displaying in the gui
   */
  public String globalInfo() {
    return 
	"Tweets the incoming string.\n"
	+ "Requires a non-anoymous " + TwitterConnection.class.getName() + " in the flow.";
  }

  /**
   * Resets the scheme.
   */
  protected void reset() {
    super.reset();

    m_Twitter = null;
  }

  /**
   * Returns the class that the consumer accepts.
   * 
   * @return		the Class of objects that can be processed
   */
  public Class[] accepts() {
    return new Class[]{String.class};
  }

  /**
   * Initializes the item for flow execution.
   *
   * @return		null if everything is fine, otherwise error message
   */
  public String setUp() {
    String	result;
    
    result = super.setUp();

    if (result == null)
      m_Twitter = TwitterUtils.getTwitterConnection(this);
    
    return result;
  }

  /**
   * Executes the flow item.
   *
   * @return		null if everything is fine, otherwise error message
   */
  protected String doExecute() {
    String	result;
    String	msg;
    
    result = null;
    
    try {
      m_Twitter.updateStatus((String) m_InputToken.getPayload());
    }
    catch (Exception e) {
      msg    = "Failed to send tweet: ";
      result = msg + e;
      getSystemErr().println(msg);
      getSystemErr().printStackTrace(e);
    }
    
    return result;
  }
}

==> adams-twitter-0.4.1-sources.jar: adams/flow/sink/Tweet.java <==
/*
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * Tweet.java
 * Copyright (C) 2012 University of Waikato, Hamilton, New Zealand
 */
package adams.flow.sink;

import adams.flow.core.TwitterUtils;
import adams.flow.standalone.TwitterConnection;

/**
 <!-- globalinfo-start -->
 <!-- globalinfo-end -->
 *
 <!-- flow-summary-start -->
 <!-- flow-summary-end -->
 *
 <!-- options-start -->
 <!-- options-end -->
 *
 * @author  fracpete (fracpete at waikato dot ac dot nz)
 * @version $Revision: 5867 $
 */
public class Tweet
  extends AbstractSink {

  /** for serialization. */
  private static final long serialVersionUID = 7284342863526697831L;

  /** for accessing the twitter API. */
  protected twitter4j.Twitter m_Twitter;

  /**
   * Returns a string describing the object.
   *
   * @return 			a description suitable for displaying in the gui
   */
  @Override
  public String globalInfo() {
    return 
	"Tweets the incoming string.\n"
	+ "Requires a non-anoymous " + TwitterConnection.class.getName() + " in the flow.";
  }

  /**
   * Resets the scheme.
   */
  @Override
  protected void reset() {
    super.reset();

    m_Twitter = null;
  }

  /**
   * Returns the class that the consumer accepts.
   * 
   * @return		the Class of objects that can be processed
   */
  public Class[] accepts() {
    return new Class[]{String.class};
  }

  /**
   * Initializes the item for flow execution.
   *
   * @return		null if everything is fine, otherwise error message
   */
  @Override
  public String setUp() {
    String	result;
    
    result = super.setUp();

    if (result == null)
      m_Twitter = TwitterUtils.getTwitterConnection(this);
    
    return result;
  }

  /**
   * Executes the flow item.
   *
   * @return		null if everything is fine, otherwise error message
   */
  @Override
  protected String doExecute() {
    String	result;
    
    result = null;
    
    try {
      m_Twitter.updateStatus((String) m_InputToken.getPayload());
    }
    catch (Exception e) {
      result = handleException("Failed to send tweet: ", e);
    }
    
    return result;
  }
}
